summaryrefslogtreecommitdiffstats
path: root/src/amd/addrlib/r800/egbaddrlib.h
diff options
context:
space:
mode:
authorXavi Zhang <[email protected]>2015-08-20 03:59:01 -0400
committerMarek Olšák <[email protected]>2017-03-30 14:44:33 +0200
commitd1ecb70ba3a8170514d08cb519faac94fdb4fe6a (patch)
tree8ee3867d37ac79d7bf56b682e7e1738154940867 /src/amd/addrlib/r800/egbaddrlib.h
parent8912862a409422da0836e4c0450ff4bbe522385d (diff)
amdgpu/addrlib: Use namespaces
Signed-off-by: Nicolai Hähnle <[email protected]>
Diffstat (limited to 'src/amd/addrlib/r800/egbaddrlib.h')
-rw-r--r--src/amd/addrlib/r800/egbaddrlib.h16
1 files changed, 11 insertions, 5 deletions
diff --git a/src/amd/addrlib/r800/egbaddrlib.h b/src/amd/addrlib/r800/egbaddrlib.h
index 6bc6c53e874..c397cfc4f81 100644
--- a/src/amd/addrlib/r800/egbaddrlib.h
+++ b/src/amd/addrlib/r800/egbaddrlib.h
@@ -27,7 +27,7 @@
/**
****************************************************************************************************
* @file egbaddrlib.h
* @brief Contains the EgBasedAddrLib class definition.
****************************************************************************************************
*/
@@ -36,7 +36,10 @@
#include "addrlib1.h"
-
+namespace Addr
+{
+namespace V1
+{
/// Structures for functions
struct CoordFromBankPipe
{
@@ -58,11 +61,11 @@ struct CoordFromBankPipe
* @note Abstract class
****************************************************************************************************
*/
-class EgBasedAddrLib : public AddrLib1
+class EgBasedLib : public Lib
{
protected:
- EgBasedAddrLib(const AddrClient* pClient);
- virtual ~EgBasedAddrLib();
+ EgBasedLib(const Client* pClient);
+ virtual ~EgBasedLib();
public:
@@ -415,5 +418,8 @@ protected:
UINT_32 m_bankInterleave; ///< Bank interleave, as a multiple of pipe interleave size
};
+} // V1
+} // Addr
+
#endif
@@ -27,7 +27,7 @@
****************************************************************************************************
* @file egbaddrlib.h
-* @brief Contains the EgBasedAddrLib class definition.
+* @brief Contains the EgBasedLib class definition.
****************************************************************************************************
*/